@@ -6,6 +6,7 @@ from django.conf import settings
 from django.core.files import File
 from django.db.models import BinaryField, BigIntegerField, CharField, TextField
 from django.forms import model_to_dict
+
 from isc_common import delAttr
 from isc_common.common.UploadItemEx import UploadItemEx
 from isc_common.fields.files import FileFieldEx
@@ -56,11 +57,11 @@ class CryptoManager(CommonManagetWithLookUpFieldsManager):
 
 class Crypto_file(AuditModel):
     format = NameField(verbose_name='Формат файла')
-    mime_type = NameField(verbose_name='MIME тип файла файла', null=True, blank=True)
+    mime_type = NameField(verbose_name='MIME тип файла файла')
     size = BigIntegerField(verbose_name='Размер фала', default=0)
-    real_name = TextField(verbose_name='Первоначальное имя файла', null=True, blank=True, db_index=True)
+    real_name = TextField(verbose_name='Первоначальное имя файла', db_index=True, unique=True)
     key = BinaryField(max_length=200, null=True, blank=True)
-    attfile = FileFieldEx(verbose_name='Файл', max_length=255, null=True, blank=True)
+    attfile = FileFieldEx(verbose_name='Файл', max_length=255)
     file_store = CharField(verbose_name='Каталог хранения файла', max_length=255, null=True, blank=True)
 
     object = CryptoManager()
@@ -94,7 +95,10 @@ class Crypto_file(AuditModel):
 
     @classmethod
     def copy_file(cls, item):
-        copyfile(src=item.real_file_name, dst=item.full_path)
+        if os.path.exists(item.real_file_name):
+            copyfile(src=item.real_file_name, dst=item.full_path)
+        else:
+            copyfile(src=item.tmp_file_name, dst=item.full_path)
         with open(item.full_path, 'rb') as src:
             fileObj = File(src)
             res, created = cls.objects.update_or_create(
@@ -108,7 +112,9 @@ class Crypto_file(AuditModel):
                     real_name=item.real_file_name,
                 )
             )
-        os.remove(item.full_path)
+
+        if os.path.exists(item.tmp_file_name):
+            os.remove(item.tmp_file_name)
 
         return res, created
 
