@@ -1,7 +1,6 @@
 import logging
 
-from isc_common.auth.managers.user_manager import UserManager
-from isc_common.auth.models.user import User
+from isc_common.auth.models.user import User, UserManager
 
 logger = logging.getLogger(__name__)
 
