@@ -1,7 +1,10 @@
-import datetime
+from bitfield import Bit
 
 
 def IsBitOn(value, bit):
+    if isinstance(bit, Bit):
+        bit = bit.number
+
     res = (value & (1 << bit))
     if isinstance(res, int):
         return res
@@ -13,10 +16,16 @@ def IsBitOff(value, bit):
 
 
 def TurnBitOn(value, bit):
+    if isinstance(bit, Bit):
+        bit = bit.number
+
     return value | (1 << bit)
 
 
 def TurnBitOff(value, bit):
+    if isinstance(bit, Bit):
+        bit = bit.number
+
     return value & ~ (1 << bit)
 
 
@@ -25,5 +34,3 @@ def CopyBit(value, bit):
         return TurnBitOn(value, bit)
     else:
         return TurnBitOff(value, bit)
-
-
