@@ -5,7 +5,6 @@ from pathlib import Path
 import magic
 from isc_common.common.UploadItem import UploadItem
 
-
 class UploadItemEx(UploadItem):
 
     def get_path(self, name):
@@ -16,9 +15,14 @@ class UploadItemEx(UploadItem):
 
         if self.real_file_name is not None and self.file_mime_type is None:
             mime = magic.Magic(mime=True)
-            self.file_mime_type = mime.from_file(self.real_file_name)
+            if os.path.exists(self.real_file_name):
+                self.file_mime_type = mime.from_file(self.real_file_name)
+                stat = Path(self.real_file_name).stat()
+            else:
+                self.file_mime_type = mime.from_file(self.tmp_file_name)
+                stat = Path(self.tmp_file_name).stat()
+
 
-        stat = Path(self.real_file_name).stat()
         if self.file_size is None:
             self.file_size = stat.st_size
 
