@@ -394,7 +394,7 @@ def create_table1(
             cursor.execute(sql_txt1, params)
             rows = cursor.fetchall()
             for row in rows:
-                # logger.debug(f'Inserting ({i} form {cnt}): Where id={row[0]}')
+                logger.debug(f'Inserting ({i} form {cnt}): Where id={row[0]}')
                 cursor.execute(sql_txt, row)
                 i += 1
 
