@@ -1,3 +1,5 @@
+import os
+
 from django.conf import settings
 from django.db.models import FileField
 from django.db.models.fields.files import FieldFile
@@ -22,6 +24,16 @@ class FieldFileEx(FieldFile, Field):
             self.file.open(mode)
         return self
 
+    def save(self, name, content, save=True):
+        name = os.path.abspath(name)
+        self.name = self.storage.save(name, content, max_length=self.field.max_length)
+        setattr(self.instance, self.field.name, self.name)
+        self._committed = True
+
+        # Save the object because it has changed, unless save is False
+        if save:
+            self.instance.save()
+
 
 class FileFieldEx(FileField):
     attr_class = FieldFileEx
