@@ -2,7 +2,7 @@ import logging
 
 
 class Logger(logging.Logger):
-    def logging(self, message, level):
+    def logging(self, message, level='info'):
         if level == 'debug':
             self.debug(message)
         elif level == 'warning':
