@@ -1,11 +1,7 @@
 import logging
 
-from django.conf import settings
 from django.core.management import BaseCommand
 
-from isc_common.ws.webSocket import WebSocket
-from kaf_pas.production.models.launches_view import Launches_viewManager
-
 logger = logging.getLogger(__name__)
 
 
