@@ -1,5 +1,7 @@
 import logging
 
+from django.db.models import SmallIntegerField
+
 from isc_common.models.base_ref import BaseRefHierarcy, BaseRefManager, BaseRefQuerySet
 
 logger = logging.getLogger(__name__)
@@ -36,6 +38,9 @@ class Image_typesManager(BaseRefManager):
 
 
 class Image_types(BaseRefHierarcy):
+    height = SmallIntegerField(null=True, blank=True)
+    width = SmallIntegerField(null=True, blank=True)
+
     objects = Image_typesManager()
 
     def __str__(self):
