@@ -4,6 +4,7 @@ from itertools import chain
 
 from bitfield import BitHandler, Bit
 from django.db.models import ForeignKey
+
 from isc_common import setAttr
 
 
@@ -129,6 +130,24 @@ def ToInt(s):
         raise Exception(f'{s} unknown type.')
 
 
+def TryToInt(s):
+    if s is None:
+        return None
+
+    try:
+        if isinstance(s, int):
+            return s
+        elif isinstance(s, str):
+            res = StrToNumber(s)
+            return res if res is not None else s
+        elif isinstance(s, float):
+            return int(s)
+        elif isinstance(s, Decimal):
+            return int(s)
+    except ValueError as ex:
+        return s
+
+
 def ToDecimal(s):
     if s is None:
         return 0
