@@ -34,7 +34,7 @@ def do(argv):
     if len(argv) < 3 or not os.path.isdir(dest_path):
         raise Exception('The path must contain the destination directory')
 
-    excl = ['.git', '.idea', 'TmpFile1', 'Programs', 'tmp']
+    excl = ['.git', '.idea', 'TmpFile1', 'Programs', 'tmp', '.php', 'templates', 'sql-log']
 
     files = []
     sized = 0
