@@ -23,8 +23,8 @@ class Chat_usersQuerySet(AuditQuerySet):
 
 class Chat_usersManager(AuditManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'chat_id': record.chat.id,
@@ -118,8 +118,8 @@ class Chat_usersManager(AuditManager):
 
             return res
 
-    @staticmethod
-    def props():
+    @classmethod
+    def props(cls):
         return BitField(flags=(
             ('compulsory_reading', 'Обязательное прочтение'),  # 1
             ('relevant', 'Актуальность'),  # 2
